@@ -30,6 +30,12 @@ def csv_zip() -> str:
     return source_path.as_posix()
 
 
+@pytest.fixture
+def dir_zip() -> str:
+    source_path = Path(__file__).parent / "data/dir.zip"
+    return source_path.as_posix()
+
+
 @pytest.fixture
 def simple_zip_data_set(simple_zip):
     return ZipFileDataSet(filepath=simple_zip)
@@ -47,7 +53,7 @@ def invalid_two_pdfs_zip_data_set(two_pdfs_zip):
 
 @pytest.fixture
 def valid_two_pdfs_zip_data_set(two_pdfs_zip):
-    return ZipFileDataSet(filepath=two_pdfs_zip, filename="simple.pdf")
+    return ZipFileDataSet(filepath=two_pdfs_zip, zipped_filename="simple.pdf")
 
 
 @pytest.fixture
@@ -55,6 +61,11 @@ def csv_zip_data_set(csv_zip):
     return ZipFileDataSet(filepath=csv_zip, dataset="pandas.CSVDataSet")
 
 
+@pytest.fixture
+def dir_zip_data_set(dir_zip):
+    return ZipFileDataSet(filepath=dir_zip)
+
+
 class TestZipFileDataSet:
 
     def test_simple_load(
@@ -95,3 +106,12 @@ class TestZipFileDataSet:
     ):
         csv_data = csv_zip_data_set.load()
         assert len(csv_data) == 2
+
+    def test_dir_dataset(
+            self,
+            simple_zip_data_set: ZipFileDataSet,
+            dir_zip_data_set: ZipFileDataSet,
+    ):
+        simple_pdf = simple_zip_data_set.load()
+        dir_data = dir_zip_data_set.load()
+        assert simple_pdf == dir_data
